@@ -1,23 +1,30 @@
 function median(arguments) {
   const { data, ignore_nodata = true } = arguments;
 
-  if (data === undefined) {
-    throw new Error("Mandatory argument `data` is not defined.");
-  }
+  validateParameter({
+    processName: "median",
+    parameterName: "data",
+    value: data,
+    required: true,
+    array: true,
+  });
 
-  if (!Array.isArray(data)) {
-    throw new Error("Argument `data` is not an array.");
-  }
-
-  if (typeof ignore_nodata !== "boolean") {
-    throw new Error("Argument `ignore_nodata` is not a boolean.");
-  }
+  validateParameter({
+    processName: "median",
+    parameterName: "ignore_nodata",
+    value: ignore_nodata,
+    nullable: false,
+    allowedTypes: ["boolean"],
+  });
 
   const newData = [];
   for (let i = 0; i < data.length; i++) {
-    if (typeof data[i] !== "number" && data[i] !== null) {
-      throw new Error("Value in argument `data` is not a number or null.");
-    }
+    validateParameter({
+      processName: "median",
+      parameterName: "element of data",
+      value: data[i],
+      allowedTypes: ["number"],
+    });
 
     if (data[i] === null) {
       if (ignore_nodata) {
