@@ -1,24 +1,32 @@
 function variance(arguments) {
   const { data, ignore_nodata = true } = arguments;
 
-  if (data === undefined || data === null) {
-    throw new Error("Mandatory argument `data` is either null or not defined.");
-  }
+  validateParameter({
+    processName: "variance",
+    parameterName: "data",
+    value: data,
+    required: true,
+    nullable: false,
+    array: true,
+  });
 
-  if (!Array.isArray(data)) {
-    throw new Error("Argument `data` is not an array.");
-  }
-
-  if (typeof ignore_nodata !== "boolean") {
-    throw new Error("Argument `ignore_nodata` is not a boolean.");
-  }
+  validateParameter({
+    processName: "variance",
+    parameterName: "ignore_nodata",
+    value: ignore_nodata,
+    nullable: false,
+    allowedTypes: ["boolean"],
+  });
 
   let sum = 0;
   let count = 0;
   for (let x of data) {
-    if (typeof x !== "number" && x !== null) {
-      throw new Error("Value in argument `data` is not a number or null.");
-    }
+    validateParameter({
+      processName: "variance",
+      parameterName: "element of data",
+      value: x,
+      allowedTypes: ["number"],
+    });
 
     if (x === null) {
       if (!ignore_nodata) {
